#!/bin/sh
#
# E-mail files and folders from the command line or a non-NeXT computer.
#
# File description and history are at the end of this script (for speed).
#
PROG="`basename $0`"
PATH=/usr/local/bin:/usr/ucb:/usr/bin:/bin
export PATH

if test -z "${AWK}" ; then
  AWK=awk
fi
CAT=cat
MAIL="/usr/ucb/Mail"
TAR="/usr/bin/gnutar cf -"
UUENCODE=uuencode

TMPDIR=/tmp/${PROG}$$.dir
TARFILE=${PROG}$$
ATTACH=${TMPDIR}/${TARFILE}.attach
INDEX=${TMPDIR}/index.rtf
TMPFILE=/tmp/${PROG}$$
USAGE="${PROG} [-] {files|folders} [addressee...]"
PROMPT="echo -n"

#
# Destroy temporary files and folders.
#
trap "/bin/rm -rf ${TMPDIR} ${TMPFILE} ; exit" 0 1 2 3 4 5 6 13 15

#
# Cycle through command-line arguments.
#
while test $# != 0 ; do
  case $1 in
    - ) # Take a message.
      echo "${PROG}: Enter mail message, terminated with single '.':"
      while test 1 = 1 ; do
	${PROMPT} "> "
        read INPUT
	if test "${INPUT}" = '.' ; then
	  break
	fi
        MAILMESSAGE="${MAILMESSAGE} ${INPUT}"
      done
      ;;
    -* ) # Unknown argument.
      echo "${PROG}: Unknown argument $1."
      ;;
    * )	# File or addressee.
      if test -r $1 ; then
	TARGET="${TARGET} $1"
	TDIR=`echo ${TARGET} | sed 's@/[^/]*$@@g'`
	cd $TDIR
	TARGET=`basename ${TARGET}`
      else
	ADDRESSEE="${ADDRESSEE} $1"
      fi
      ;;
  esac
  shift
done

#
# Quit if no files specified on the command line.
#
if test -z "${TARGET}" ; then
  echo "${PROG}: No files to send." >&2
  echo "${USAGE}" >&2
  exit 1
#
# Insert generic message if MAILMESSAGE is empty.
#
elif test -z "${MAILMESSAGE}" ; then
  MAILMESSAGE="This NeXTmail bundled by ${PROG}."
else
#
# Prompt for ADDRESSEE if empty.
#
  while test -z "${ADDRESSEE}" ; do
    ${PROMPT} "To: "
    read ADDRESSEE
  done
fi

#
# Create temporary directory to work in.
#
mkdir ${TMPDIR}

#
# Create index.rtf file that includes MAILMESSAGE text.
#
cat << EOF > ${INDEX}
{\rtf0\ansi{\fonttbl\f0\fswiss Helvetica;}
\margl120
\margr120
\pard\tx533\tx1067\tx1601\tx2135\tx2668\tx3202\tx3736\tx4270\tx4803\tx5337\f0\b0\i0\ul0\fs24 ${MAILMESSAGE}
EOF

#
# Cycle through TARGET list and append attachment lines to index.rtf file.
#
for x in ${TARGET} ; do
  echo "{{\attachment0 $x" >> ${INDEX}
  echo "}" >> ${INDEX}
done

#
# End of index.rtf.
#
echo "}" >> ${INDEX}

#
# Print an informative status message on stderr.
#
echo ${PROG}: Bundling ${TARGET} for shipment via NeXTmail to ${ADDRESSEE}. >&2

#
# Create a tar'ed | compressed .attach file.
#
${TAR} ${TARGET} -C ${TMPDIR} index.rtf | compress > ${ATTACH}

#
# Go into the temporary folder.
#
cd ${TMPDIR}

#
# Uuencode .attach file and give it a .tar.nnnn. prefix.
#
${UUENCODE} ${ATTACH} .tar.$$.${TARFILE} > ${TMPFILE}

#
# Add the Next-Attachment keyword.
#

echo "Next-Attachment: .tar.$$.${TARFILE}, `wc -c ${ATTACH} | ${AWK} '{print $1}'`, 1/1, 9999, 0" > ${ATTACH}
echo "" >> ${ATTACH}

#
# Append the uuencoded file.
#
${CAT} ${TMPFILE} >> ${ATTACH}

#
# Deliver the mail via e-mail.
#
${MAIL} -s "[NoSD/submission]:${TARGET}" ${ADDRESSEE} < ${ATTACH}

exit $?

# 
# $Header: /Net/spa/Users/Source/Next/RCS/next-mail,v 1.3 1991/09/17 16:01:05 treed Exp $
# Locker: $Locker:  $
# Author and Modification Date: $Author: treed $ $Date: 1991/09/17 16:01:05 $
# File name and Description: 
# Send NeXTmail(c) from the command line.  This script can be used from a Next or
# non-Next computer.  You may specify files and folders to send and recipients
# to receive the e-mail; if the thing on the command line is not a folder or file,
# then next-mail assumes that it is a recipient.  You may also specify a '-' and
# type accompanying e-mail text when prompted.
#
# Feel free to distribute this script, just don't charge money for it.
# Tim Reed <treed@gun.com>
#
# Copyright (c) 1991 Timothy Reed.  All rights reserved.
# WARNING: You may use and distribute this software, but you use it at your own risk.
#
# This program is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public LIcense as published by the Free Software Foundation.
# This software comes with ABSOLUTELY NO WARRANTY.
#
